Learn R Programming

qqr (version 0.0.1)

BRSoccer2014: Table of the 2014th Brazilian Soccer Championship.

Description

This data set gives the position of each Brazilian soccer team in the 2014th championship with the number of points, games played, victories, ties, defeats, goal difference, goals scored and goals suffered.

Usage

BRSoccer2014

Arguments

Format

A data frame with 20 rows and 9 variables

Times

name of the teams

P

number of points scored (3 * V + E)

J

number of matches played (V + E + D)

V

number of victories

E

number of ties

D

number of defeats

SG

goals difference (G - GC)

G

goals scored

GC

goals suffered