This data set gives the position of each Brazilian soccer team in the 2014th championship with the number of points, games played, victories, ties, defeats, goal difference, goals scored and goals suffered.
BRSoccer2014A data frame with 20 rows and 9 variables
name of the teams
number of points scored (3 * V + E)
number of matches played (V + E + D)
number of victories
number of ties
number of defeats
goals difference (G - GC)
goals scored
goals suffered